@@ -1,12 +1,12 @@
 eos = require('eosjs')
-ecc = require('eosjs-ecc');
+ecc = require('eosjs-ecc-eva');
 
 function generate_eos_keys() {
   return ecc.randomKey().then(privateKey => {
     const publicKey = ecc.privateToPublic(privateKey);
     return {
-      'private': privateKey,
-      'public': publicKey
+      "private": privateKey,
+      "public": publicKey
     }
   }).then(responseData => {
     return responseData;
