@@ -1,16 +1,18 @@
 Eos = require('eosjs') // Eos = require('./src')
 
 const httpEndpointAddress = process.argv[2];
-const wif = process.argv[3];
-const contract_account = process.argv[4];
-const contract_function = process.argv[5];
-const authorization_actor = process.argv[6];
-const authorization_permission = process.argv[7];
-const data_values = JSON.parse(process.argv[8]);
+const chain_id = process.argv[3];
+const wif = process.argv[4];
+const contract_account = process.argv[5];
+const contract_function = process.argv[6];
+const authorization_actor = process.argv[7];
+const authorization_permission = process.argv[8];
+const data_values = JSON.parse(process.argv[9]);
 
 eos = Eos({
   keyProvider: wif,
-  httpEndpoint: httpEndpointAddress
+  httpEndpoint: httpEndpointAddress,
+  chainId: chain_id
 })
 
 
@@ -27,7 +29,7 @@ eos.transaction({
     }
   ]
 }).then(function (value){
-        console.log(value);
+        console.log(JSON.stringify(value));
         return value;
       }).catch(function (e) {
       console.error(e);
